import java.io.*;
/**
 * Implement the empty methods of this class to create a 
 * fully function SAT solver using the Davis-Putnam Procedure.
 * Creation date: (9/25/00 4:27:28 PM)
 * @author: Todd Neller
 */
public abstract class SatSolver {
	/** After numbering the variables, record how many there are here. */
	public int variables;
	/** After converting to CNF, record the number of clauses here. */
	public int clauses;
/**
 * SatSolver constructor comment.
 */
public SatSolver() {
	super();
}
/**
 * Convert the parse tree to CNF.  You don't have to use class WFF as
 * your internal representation, but be sure to comment on your
 * representation choices thoroughly.
 * Converting to CNF is not trivial.  Give yourself plenty of time and
 * code this part days in advance of DPsolve().
 * Creation date: (9/26/00 1:29:52 AM)
 * @param parseTree java.util.Vector
 */
public static void convertToCNF(java.util.Vector parseTree) {}
/**
 * If you've picked a good representation, this should be little harder
 * than Depth-First Search.  Here are a few tips for efficiency:
 * - Don't both representing separate search states.  Write a recursive
 * procedure that "undoes" changes when backtracking.
 * - Keeping track of the number of unassigned literals in remaining
 * unsatisfied clauses may provide opportunity for good search heuristics.
 * - Give yourself time to thoroughly work out the design on paper and in
 * your mind before coding.
 * - Don't wait until the last minute!
 * Creation date: (9/26/00 1:32:53 AM)
 */
public static void DPsolve() {}
/**
 * Starts the application.
 * @param args an array of command-line arguments
 */
public static void main(java.lang.String[] argv) throws ParseException {
	WFFParse parser = new WFFParse(System.in);
	// Read propositional logic from standard input.
	while (parser.readWFFs() != 0);
	
	// Retrieve parse tree.
	java.util.Vector parseTree = parser.wffVector;
	
	// Number propositions 0...n-1
	numberPropositions(parseTree);
	
	// Convert propositions to CNF.
	convertToCNF(parseTree);

	// Print CNF representation.
	printCNF();
	
	// Use Davis-Putnam procedure on CNF KB.
	DPsolve();
	
	// Report results.
	reportResults();
	
}
/**
 * Number the propositions.  A simple depth first traversal of the parse
 * tree and a well-chosen data structure should make life simple.
 * Creation date: (9/26/00 1:27:38 AM)
 * @param parseTree java.util.Vector
 */
public static void numberPropositions(java.util.Vector parseTree) {}
/**
 * Print in CNF format using variable numbers + 1 and notation such that
 * you could use this output as input to GSAT.
 * Creation date: (9/26/00 1:32:15 AM)
 */
public static void printCNF() {}
/**
 * Report results.  If there is a satisfying truth assignment, list the
 * proposition, assignment pairs one per line.  If there is no satisfying
 * truth assignment, simply print "UNSATISFIABLE".
 * Creation date: (9/26/00 1:33:19 AM)
 */
public static void reportResults() {}
}
